@@ -19,5 +19,8 @@ class FromDateOp(Enum):
 class ToDateOp(Enum):
     STR_TO_DATE = auto()
     PARSE_DATE = auto()
+    DATE_PARSE = auto()
     TIMESTAMP = auto()
+    TO_TIMESTAMP = auto()
     TO_TIMESTAMP_NTZ = auto()
+    TO_DATE = auto()
