@@ -1,9 +1,9 @@
-from typing import Literal, Union
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.combination import Reference
 
 
 class DomainStep(BaseStep):
-    name: Literal['domain'] = 'domain'
-    domain: Union[str, Reference]
+    name: Literal["domain"] = "domain"
+    domain: str | Reference
